[Scummvm-cvs-logs] CVS: scummvm/sky logic.cpp,1.20,1.21

Oliver Kiehl olki at users.sourceforge.net
Fri May 2 05:28:50 CEST 2003


Update of /cvsroot/scummvm/scummvm/sky
In directory sc8-pr-cvs1:/tmp/cvs-serv25275

Modified Files:
	logic.cpp 
Log Message:
renamed shadowed var


Index: logic.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/sky/logic.cpp,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -d -r1.20 -r1.21
--- logic.cpp	2 May 2003 11:57:32 -0000	1.20
+++ logic.cpp	2 May 2003 12:16:50 -0000	1.21
@@ -307,21 +307,21 @@
 		}
 	};
 
-	uint16 **anim = (uint16 **)SkyCompact::getCompactElem(_compact,
+	uint16 **animList = (uint16 **)SkyCompact::getCompactElem(_compact,
 			C_ANIM_UP + _compact->extCompact->megaSet + dir * 4);
 
 	uint16 arAnimIndex = _compact->extCompact->arAnimIndex;
-	if (!(*anim)[arAnimIndex/2]) {
+	if (!(*animList)[arAnimIndex/2]) {
 		 arAnimIndex = 0;
 		_compact->extCompact->arAnimIndex = 0; // reset
 	}
 
 	_compact->extCompact->arAnimIndex += S_LENGTH;
 
-	*sequence       -= (*anim)[(S_COUNT + arAnimIndex)/2]; // reduce the distance to travel
-	_compact->frame  = (*anim)[(S_FRAME + arAnimIndex)/2]; // new graphic frame
-	_compact->xcood += (*anim)[(S_AR_X  + arAnimIndex)/2]; // update x coordinate
-	_compact->ycood += (*anim)[(S_AR_Y  + arAnimIndex)/2]; // update y coordinate
+	*sequence       -= (*animList)[(S_COUNT + arAnimIndex)/2]; // reduce the distance to travel
+	_compact->frame  = (*animList)[(S_FRAME + arAnimIndex)/2]; // new graphic frame
+	_compact->xcood += (*animList)[(S_AR_X  + arAnimIndex)/2]; // update x coordinate
+	_compact->ycood += (*animList)[(S_AR_Y  + arAnimIndex)/2]; // update y coordinate
 }
 
 void SkyLogic::arTurn() {





More information about the Scummvm-git-logs mailing list